@@ -6,10 +6,22 @@ from os.path import basename, splitext, dirname
 import argparse
 import sqlite3
 
-from predectorutils.indexedresults import ResultsTable, ResultRow, DecoderRow
+from typing import Iterator, TextIO
+
+from predectorutils.database import (
+    load_db,
+    ResultsTable,
+    ResultRow,
+    DecoderRow
+)
 
 
 def cli(parser: argparse.ArgumentParser) -> None:
+    parser.add_argument(
+        "db",
+        type=str,
+        help="Where the sqlite database is"
+    )
 
     parser.add_argument(
         "map",
@@ -17,12 +29,6 @@ def cli(parser: argparse.ArgumentParser) -> None:
         help="Where to save the id mapping file."
     )
 
-    parser.add_argument(
-        "infile",
-        type=argparse.FileType("r"),
-        help="The input ldjson file to decode.",
-    )
-
     parser.add_argument(
         "-t", "--template",
         type=str,
@@ -31,10 +37,13 @@ def cli(parser: argparse.ArgumentParser) -> None:
     )
 
     parser.add_argument(
-        "--db",
-        type=str,
-        default=":memory:",
-        help="Where to store the database"
+        "--mem",
+        type=float,
+        default=1.0,
+        help=(
+            "The amount of RAM in gibibytes to let "
+            "SQLite use for cache."
+        )
     )
 
     return
@@ -48,12 +57,28 @@ def make_outdir(filename: str) -> None:
     return
 
 
-def inner(con: sqlite3.Connection, args: argparse.Namespace) -> None:
-    cur = con.cursor()
+def write_results(
+    handle: TextIO,
+    results: Iterator[ResultRow],
+) -> None:
+    buf = []
+    for line in results:
+        buf.append(line.as_str())
+        if len(buf) > 10000:
+            print("\n".join(buf), file=handle)
+            buf = []
 
+    if len(buf) > 0:
+        print("\n".join(buf), file=handle)
+    return
+
+
+def inner(
+    con: sqlite3.Connection,
+    cur: sqlite3.Cursor,
+    args: argparse.Namespace
+) -> None:
     tab = ResultsTable(con, cur)
-    tab.create_tables()
-    tab.insert_results(ResultRow.from_file(args.infile))
     tab.insert_decoder(DecoderRow.from_file(args.map))
 
     for fname, decoded in tab.decode():
@@ -62,42 +87,17 @@ def inner(con: sqlite3.Connection, args: argparse.Namespace) -> None:
             filename=fname,
             filename_noext=filename_noext,
         )
-
-        first_chunk = True
-
-        buf = []
-        for line in decoded:
-            buf.append(line)
-            if len(buf) > 10000:
-                if first_chunk:
-                    make_outdir(filename)
-                    mode = "w"
-                    first_chunk = False
-                else:
-                    mode = "a"
-
-                with open(filename, mode) as handle:
-                    print("\n".join(buf), file=handle)
-                buf = []
-
-        if len(buf) > 0:
-            if first_chunk:
-                make_outdir(filename)
-                mode = "w"
-                first_chunk = False
-            else:
-                mode = "a"
-
-            with open(filename, mode) as handle:
-                print("\n".join(buf), file=handle)
+        make_outdir(filename)
+        with open(filename, "w") as handle:
+            write_results(handle, decoded)
 
     return
 
 
 def runner(args: argparse.Namespace) -> None:
-    con = sqlite3.connect(args.db)
     try:
-        inner(con, args)
+        con, cur = load_db(args.db, args.mem)
+        inner(con, cur, args)
     except Exception as e:
         raise e
     finally:
